import React from 'react';
import ReactDOM from 'react-dom';
import { arc } from 'd3';

const width = 960;
const height = 500;
const centerX = width / 2;
const centerY = height / 2;
const strokeWidth = 20;
const eyeOffsetX = 90;
const eyeOffsetY = 60;
const eyeRadius = 40;
const mouthWidth = 20;
const mouthRadius = 140;
const accentColor = 'khaki';

const mouthArc = arc()
  .innerRadius(mouthRadius)
  .outerRadius(mouthRadius + mouthWidth)
  .startAngle(Math.PI / 2)
  .endAngle((Math.PI * 3) / 2);

const App = () => (
  <svg width={width} height={height}>
    <defs>
      <linearGradient
        id="faceFillGradient"
        x1="0%"
        x2="100%"
        y1="0%"
        y2="0%"
      >
        <stop offset="0%" stopColor="white"></stop>
        <stop
          offset="100%"
          stopColor="black"
          stopOpacity="1"
        ></stop>
      </linearGradient>
      <linearGradient
        id="accentFillGradient"
        x1="0%"
        x2="100%"
        y1="0%"
        y2="0%"
      >
        <stop offset="0%" stopColor="black"></stop>
        <stop
          offset="100%"
          stopColor="white"
          stopOpacity="1"
        ></stop>
      </linearGradient>
    </defs>
    <g transform={`translate(${centerX},${centerY})`}>
      <circle // face
        r={centerY - strokeWidth / 2}
        fill="url(#faceFillGradient)"
        stroke="url(#accentFillGradient)"
        stroke-width={strokeWidth}
      />
      <circle // left eye
        cx={-eyeOffsetX}
        cy={-eyeOffsetY}
        r={eyeRadius}
        fill={accentColor}
      />
      <circle // right eye
        cx={eyeOffsetX}
        cy={-eyeOffsetY}
        r={eyeRadius}
        fill={accentColor}
      />
      <path // mouth
        d={mouthArc()}
        fill={accentColor} />
    </g>
  </svg>
);

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
